<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
import { dateRangeOptions } from '@/utils/options'
import CustomDateRange from '@/components/custom-date-range.vue'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/feedback/page',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        columns: [
          { label: '反馈人', prop: 'customerName', minWidth: 120 },
          { label: '反馈人电话', prop: 'customerTel', minWidth: 150 },
          {
            label: '反馈内容',
            prop: 'feedBack',
            minWidth: 250,
            showOverflowTooltip: true,
          },
          { label: '反馈时间', prop: 'createTime', minWidth: 180 },
          {
            label: '回复内容',
            prop: 'reply',
            minWidth: 250,
            showOverflowTooltip: true,
          },
          { label: '回复时间', prop: 'replyTime', minWidth: 180 },
        ],
        operationAttrs: {
          width: 120,
          fixed: 'right',
        },
        searchFormAttrs: {
          labelWidth: 'auto',
        },
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '处理状态：',
                id: 'handled',
                type: 'bus-radio',
                el: {
                  hasAll: true,
                  childType: 'el-radio-button',
                  fromDict: false,
                  options: [
                    { label: '已处理', value: true },
                    { label: '待处理', value: false },
                  ],
                },
                default: '',
                span: 24,
                searchImmediately: true,
              },
              {
                label: '反馈日期：',
                id: 'dateType',
                component: CustomDateRange,
                el: {
                  options: dateRangeOptions,
                },
                searchImmediately: true,
                commonFormat: true,
                commonFormatProps: [
                  'dateType',
                  'createDateBeginStr',
                  'createDateEndStr',
                ],
                span: 24,
              },
              { label: '反馈人：', id: 'name', type: 'input' },
              { label: '反馈人电话：', id: 'tel', type: 'input' },
            ],
          },
        ],
        form: [
          { label: '反馈人：', id: 'customerName', type: 'input' },
          { label: '反馈人电话：', id: 'customerTel', type: 'input' },
          {
            label: '反馈内容：',
            id: 'feedBack',
            type: 'input',
            el: { type: 'textarea' },
          },
          { label: '反馈时间：', id: 'createTime', type: 'input' },
          {
            label: '回复内容：',
            id: 'reply',
            type: 'input',
            el: { type: 'textarea' },
          },
          { label: '回复时间：', id: 'replyTime', type: 'input' },
        ],
        extraButtons: [
          {
            text: '回复',
            show: (row) => !row.handled,
            atClick: (row) => {
              this.$refs.crud.$refs.extraDialog[0].show(row)
            },
          },
        ],
        extraDialogs: [
          {
            title: '回复',
            hiddenReverseItems: [],
            form: [
              {
                label: '回复内容：',
                id: 'reply',
                type: 'input',
                el: {
                  rows: 6,
                  type: 'textarea',
                },
                rules: {
                  required: true,
                  message: '请输入回复内容',
                  trigger: 'blur',
                },
              },
            ],
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/feedback/page/reply',
                {
                  method: 'post',
                  data: val,
                }
              )
              if (code === 0) {
                this.$message.success('回复成功')
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '投诉反馈',
    }
  },
}
</script>

<style lang="scss" scoped></style>
